==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/GetChannelPolicyRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetChannelPolicyRequest(channelName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyRequest = {
    import GetChannelPolicyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyRequest
      .builder()
      .channelName(__string.unwrap(channelName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.GetChannelPolicyRequest.ReadOnly =
    zio.aws.mediatailor.model.GetChannelPolicyRequest.wrap(buildAwsValue())
}
object GetChannelPolicyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.GetChannelPolicyRequest =
      zio.aws.mediatailor.model.GetChannelPolicyRequest(channelName)
    def channelName: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyRequest
  ) extends zio.aws.mediatailor.model.GetChannelPolicyRequest.ReadOnly {
    override val channelName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.channelName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyRequest
  ): zio.aws.mediatailor.model.GetChannelPolicyRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-mediatailor_3-5.17.225.2-sources.jar: zio/aws/mediatailor/model/GetChannelPolicyRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetChannelPolicyRequest(channelName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyRequest = {
    import GetChannelPolicyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyRequest
      .builder()
      .channelName(channelName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.GetChannelPolicyRequest.ReadOnly =
    zio.aws.mediatailor.model.GetChannelPolicyRequest.wrap(buildAwsValue())
}
object GetChannelPolicyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.GetChannelPolicyRequest =
      zio.aws.mediatailor.model.GetChannelPolicyRequest(channelName)
    def channelName: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyRequest
  ) extends zio.aws.mediatailor.model.GetChannelPolicyRequest.ReadOnly {
    override val channelName: __string = impl.channelName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyRequest
  ): zio.aws.mediatailor.model.GetChannelPolicyRequest.ReadOnly = new Wrapper(
    impl
  )
}
